@@ -15,7 +15,8 @@ except ImportError:
     from httplib import HTTPException
 import socket
 import urllib3
-import urllib3.util
+from urllib3.exceptions import HTTPError
+from urllib3.exceptions import ReadTimeoutError
 import json
 import ssl
 import dns.resolver
@@ -205,6 +206,23 @@ class Client(object):
             _log.debug("Machines cache initialised to %s",
                        self._machines_cache)
 
+        # Versions set to None. They will be set upon first usage.
+        self._version = self._cluster_version = None
+
+    def _set_version_info(self):
+        """
+        Sets the version information provided by the server.
+        """
+        # Set the version
+        version_info = json.loads(self.http.request(
+            self._MGET,
+            self._base_uri + '/version',
+            headers=self._get_headers(),
+            timeout=self.read_timeout,
+            redirect=self.allow_redirect).data.decode('utf-8'))
+        self._version = version_info['etcdserver']
+        self._cluster_version = version_info['etcdcluster']
+
     def _discover(self, domain):
         srv_name = "_etcd._tcp.{}".format(domain)
         answers = dns.resolver.query(srv_name, 'SRV')
@@ -288,9 +306,7 @@ class Client(object):
             ]
             _log.debug("Retrieved list of machines: %s", machines)
             return machines
-        except (urllib3.exceptions.HTTPError,
-                HTTPException,
-                socket.error) as e:
+        except (HTTPError, HTTPException, socket.error) as e:
             # We can't get the list of machines, if one server is in the
             # machines cache, try on it
             _log.error("Failed to get list of machines from %s%s: %r",
@@ -375,6 +391,25 @@ class Client(object):
         except (TypeError,ValueError):
             raise etcd.EtcdException("Cannot parse json data in the response")
 
+    @property
+    def version(self):
+        """
+        Version of etcd.
+        """
+        if not self._version:
+            self._set_version_info()
+        return self._version
+
+    @property
+    def cluster_version(self):
+        """
+        Version of the etcd cluster.
+        """
+        if not self._cluster_version:
+            self._set_version_info()
+
+        return self._cluster_version
+
     @property
     def key_endpoint(self):
         """
@@ -719,9 +754,9 @@ class Client(object):
             client.EtcdResult
 
         Raises:
-            KeyValue:  If the key doesn't exists.
+            KeyValue:  If the key doesn't exist.
 
-            urllib3.exceptions.TimeoutError: If timeout is reached.
+            etcd.EtcdWatchTimedOut: If timeout is reached.
 
         >>> print client.watch('/key').value
         'value'
@@ -802,7 +837,6 @@ class Client(object):
     def _wrap_request(payload):
         @wraps(payload)
         def wrapper(self, path, method, params=None, timeout=None):
-            some_request_failed = False
             response = False
 
             if timeout is None:
@@ -815,6 +849,7 @@ class Client(object):
                 raise ValueError('Path does not start with /')
 
             while not response:
+                some_request_failed = False
                 try:
                     response = payload(self, path, method,
                                        params=params, timeout=timeout)
@@ -828,12 +863,10 @@ class Client(object):
                     _ = response.data
                     # urllib3 doesn't wrap all httplib exceptions and earlier versions
                     # don't wrap socket errors either.
-                except (urllib3.exceptions.HTTPError,
-                        HTTPException, socket.error) as e:
+                except (HTTPError, HTTPException, socket.error) as e:
                     if (isinstance(params, dict) and
                         params.get("wait") == "true" and
-                        isinstance(e,
-                                   urllib3.exceptions.ReadTimeoutError)):
+                        isinstance(e, ReadTimeoutError)):
                         _log.debug("Watch timed out.")
                         raise etcd.EtcdWatchTimedOut(
                             "Watch timed out: %r" % e,
@@ -870,7 +903,7 @@ class Client(object):
                     if not self._use_proxies:
                         # The cluster may have changed since last invocation
                         self._machines_cache = self.machines
-                    self._machines_cache.remove(self._base_uri)
+                        self._machines_cache.remove(self._base_uri)
             return self._handle_server_response(response)
         return wrapper
 
