@@ -121,6 +121,58 @@ class TestClient(unittest.TestCase):
             'authorization': 'Basic dXNlcm5hbWU6cGFzc3dvcmQ='
         }
 
+    def test__set_version_info(self):
+        """Verify _set_version_info makes the proper call to the server"""
+        with mock.patch('urllib3.PoolManager') as _pm:
+            _request = _pm().request
+            # Return the expected data type
+            _request.return_value = mock.MagicMock(
+                data=b'{"etcdserver": "2.2.3", "etcdcluster": "2.3.0"}')
+
+            # Create the client and make the call.
+            client = etcd.Client()
+            client._set_version_info()
+
+            # Verify we call the proper endpoint
+            _request.assert_called_once_with(
+                client._MGET,
+                client._base_uri + '/version',
+                headers=mock.ANY,
+                redirect=mock.ANY,
+                timeout=mock.ANY)
+
+            # Verify the properties while we are here
+            self.assertEquals('2.2.3', client.version)
+            self.assertEquals('2.3.0', client.cluster_version)
+
+    def test_version_property(self):
+        """Ensure the version property is set on first access."""
+        with mock.patch('urllib3.PoolManager') as _pm:
+            _request = _pm().request
+            # Return the expected data type
+            _request.return_value = mock.MagicMock(
+                data=b'{"etcdserver": "2.2.3", "etcdcluster": "2.3.0"}')
+
+            # Create the client.
+            client = etcd.Client()
+
+            # Verify the version property is set
+            self.assertEquals('2.2.3', client.version)
+
+    def test_cluster_version_property(self):
+        """Ensure the cluster version property is set on first access."""
+        with mock.patch('urllib3.PoolManager') as _pm:
+            _request = _pm().request
+            # Return the expected data type
+            _request.return_value = mock.MagicMock(
+                data=b'{"etcdserver": "2.2.3", "etcdcluster": "2.3.0"}')
+
+            # Create the client.
+            client = etcd.Client()
+
+            # Verify the cluster_version property is set
+            self.assertEquals('2.3.0', client.cluster_version)
+
     def test_get_headers_without_auth(self):
         client = etcd.Client()
         assert client._get_headers() == {}
